@@ -68,19 +68,15 @@ rowRanks <- function(x, rows = NULL, cols = NULL,
   # Argument 'ties.method':
   ties.method <- ties.method[1L]
 
-  if (is.element("flavor", names(list(...)))) {
-    .Defunct(msg = "Argument 'flavor' of rowRanks() is defunct.",
-             package = "matrixStats")
-  }
-
-  tiesMethod <- charmatch(ties.method, c("max", "average", "min"), nomatch = 0L)
-  if (tiesMethod == 0L) {
+  ties_method <- charmatch(ties.method, c("max", "average", "min"),
+                           nomatch = 0L)
+  if (ties_method == 0L) {
     stop("Unknown value of argument 'ties.method': ", ties.method)
   }
 
   dim. <- as.integer(dim.)
   # byrow = TRUE
-  .Call(C_rowRanksWithTies, x, dim., rows, cols, tiesMethod, TRUE)
+  .Call(C_rowRanksWithTies, x, dim., rows, cols, ties_method, TRUE)
 }
 
 
@@ -92,22 +88,18 @@ colRanks <- function(x, rows = NULL, cols = NULL,
   # Argument 'ties.method':
   ties.method <- ties.method[1L]
 
-  if (is.element("flavor", names(list(...)))) {
-    .Defunct(msg = "Argument 'flavor' of colRanks() is defunct.",
-             package = "matrixStats")
-  }
-
   # Argument 'preserveShape'
   preserveShape <- as.logical(preserveShape)
 
-  tiesMethod <- charmatch(ties.method, c("max", "average", "min"), nomatch = 0L)
-  if (tiesMethod == 0L) {
+  ties_method <- charmatch(ties.method, c("max", "average", "min"),
+                           nomatch = 0L)
+  if (ties_method == 0L) {
     stop("Unknown value of argument 'ties.method': ", ties.method)
   }
 
   dim. <- as.integer(dim.)
   # byrow = FALSE
-  y <- .Call(C_rowRanksWithTies, x, dim., rows, cols, tiesMethod, FALSE)
+  y <- .Call(C_rowRanksWithTies, x, dim., rows, cols, ties_method, FALSE)
   if (!preserveShape) y <- t(y)
   y
 }
